<?php
//
// Perfdata Sub-Component Functions
// Copyright (c) 2008-2018 Nagios Enterprises, LLC. All rights reserved.
//

include_once(dirname(__FILE__).'/../componenthelper.inc.php');


perfdata_component_init();


////////////////////////////////////////////////////////////////////////
// COMPONENT INIT FUNCTIONS
////////////////////////////////////////////////////////////////////////


function perfdata_component_init()
{
    $name = "perfdata";
    $args = array(
        COMPONENT_NAME => $name,
        COMPONENT_TITLE => "Performance Graphing",
        COMPONENT_AUTHOR => "Nagios Enterprises, LLC",
        COMPONENT_DESCRIPTION => "Provides integrated performance graphing functionality.",
        COMPONENT_PROTECTED => true,
        COMPONENT_TYPE => COMPONENT_TYPE_CORE
    );
    register_component($name, $args);
}


////////////////////////////////////////////////////////////////////////
// URL FUNCTIONS
////////////////////////////////////////////////////////////////////////


/**
 * @param bool $directory_only
 * @return string
 */
function perfdata_get_component_url($directory_only = false)
{
    $url = get_base_url();
    $url .= "/includes/components/perfdata/";
    if (!$directory_only) {
        $url .= "perfdata.php";
    }
    return $url;
}


/**
 * @param string $hostname
 * @param string $servicename
 * @return bool
 */
function perfdata_chart_exists($hostname = "", $servicename = "_HOST_")
{
    return pnp_chart_exists($hostname, $servicename);
}


/**
 * @param string $hostname
 * @param string $servicename
 * @param int    $source
 * @param int    $view
 * @param string $start
 * @param string $end
 * @param int    $host_id
 * @param int    $service_id
 * @return string
 */
function perfdata_get_graph_image_url($hostname = "", $servicename = "_HOST_", $source = 1, $view = PNP_VIEW_DEFAULT, $start = "", $end = "", $host_id = -1, $service_id = -1)
{
    // No perfdata exists in pnp
    if (!pnp_chart_exists($hostname, $servicename)) {
        $url = perfdata_get_component_url(true);
        $url .= "noperfdata.png?";
    } else {
        $url = perfdata_get_api_url($hostname, $servicename, $source, $view, $start, $end);
    }
    return $url;
}


/**
 * @param string $hostname
 * @param string $service
 * @param int    $source
 * @param int    $view
 * @param string $start
 * @param string $end
 * @return string
 */
function perfdata_get_api_url($hostname = "", $service = "_HOST_", $source = 1, $view = PNP_VIEW_DEFAULT, $start = "", $end = "")
{
    $service = urlencode(str_replace(" ", "_", $service));
    $url = get_base_url()."includes/components/perfdata/graphApi.php?host=$hostname&service=$service&source=$source&view=$view&start=$start&end=$end";
    return $url; 
}


/**
 * @param string $hostname
 * @param string $servicename
 * @param bool   $usetemplate
 * @return array
 */
function perfdata_get_service_sources($hostname = "", $servicename = "_HOST_", $usetemplate = true)
{
    $views = pnp_read_service_views($hostname, $servicename, $usetemplate);
    return $views;
}


/**
 * @param        $sourcename
 * @param string $template
 * @return mixed
 */
function perfdata_get_friendly_source_name($sourcename, $template = "defaults")
{
    $name = $sourcename;

    if ($template == 'defaults') {

        $defaults = array(
            "time" => _("Time"),
            "size" => _("Size"),
            "pl" => _("Packet Loss"),
            "rta" => _("Round Trip Average"),
            "load1" => _("1 Minute Load"),
            "load5" => _("5 Minute Load"),
            "load15" => _("15 Minute Load"),
            "users" => _("Users")
        );

        if (array_key_exists($sourcename, $defaults)) {
            $name = $defaults[$sourcename];
        }

    } else if ($template == 'check_ping') {

        switch ($sourcename) {
            case 'rta':
                $name = _("Round Trip Average");
                break;
            case 'pl':
                $name = _("Packet Loss");
                break;
        }

    } else if ($template == 'check_http') {

        switch ($sourcename) {
            case 'time':
                $name = _("Response Time");
                break;
            case 'size':
                $name = _("Page Size");
                break;
            case 'ds1':
                $name = _("Response Time");
                break;
            case 'ds2':
                $name = _("Page Size");
                break;
        }

    } else if ($template == 'check_dns') {

        switch ($sourcename) {
            case 'time':
                $name = _("Response Time");
                break;
        }

    } else if ($template == 'check_local_load') {

        switch ($sourcename) {
            case 'ds1':
                $name = _("CPU Load");
                break;
        }

    }

    return $name;
}


////////////////////////////////////////////////////////////////////////
// OUTPUT FUNCTIONS
////////////////////////////////////////////////////////////////////////


/**
 * @param string $hostname
 * @param string $servicename
 * @param int    $source
 * @param int    $view
 * @param string $start
 * @param string $end
 * @param string $title
 * @param string $width
 * @param string $height
 * @param int    $host_id
 * @param int    $service_id
 *
 * @return string
 */
function perfdata_get_direct_graph_image_html($hostname = "", $servicename = "", $source = 1, $view = PNP_VIEW_DEFAULT, $start= "", $end = "", $title = "", $width = "", $height = "", $host_id = -1, $service_id = -1)
{
    $url = perfdata_get_graph_image_url($hostname,$servicename,$source,$view,$start,$end,$host_id,$service_id);
    $html = "<img src='".$url."' alt='".$title."' title='".$title."' class='perfdatachart'";
    if (have_value($width)) {
        $html .= " width='$width'";
    }
    if (have_value($height)) {
        $html .= " height='$height'";
    }
    $html .= ">";
    return $html;
}


/**
 * @return string
 */
function perfdata_rrdtool_path()
{
    global $cfg;
    return (!empty($cfg["component_info"]["perfdata"]["rrdtool_path"])) ? $cfg["component_info"]["perfdata"]["rrdtool_path"] : "/usr/bin/rrdtool";
}
